@@ -5,9 +5,9 @@ BEGIN {
       'Module::Compile'     => 'PDL/NiceSlice/ModuleCompile.pm',
    );  # to validate names
 
-   $PDL::NiceSlice::engine = $engine_ok{'Filter::Simple'};  # default engine type
+   ## $PDL::NiceSlice::engine = $engine_ok{'Filter::Simple'};  # default engine type
    ## TODO: Add configuration argument to perldl.conf
-   ## $PDL::NiceSlice::engine = $engine_ok{'Filter::Util::Call'};  # default engine type
+   $PDL::NiceSlice::engine = $engine_ok{'Filter::Util::Call'};  # default engine type
 
    if ( exists $ENV{PDL_NICESLICE_ENGINE} ) {
       my $engine = $ENV{PDL_NICESLICE_ENGINE};
@@ -26,7 +26,7 @@ no warnings;
 
 package PDL::NiceSlice;
 
-our $VERSION = '1.000_003';
+our $VERSION = '1.001';
 $VERSION = eval $VERSION;
 
 $PDL::NiceSlice::debug = defined($PDL::NiceSlice::debug) ? $PDL::NiceSlice::debug : 0;
@@ -1104,12 +1104,9 @@ the bottom.
 
 Feedback and bug reports are welcome. Please include an example
 that demonstrates the problem. Log bug reports in the PDL
-bug database at
-
-  http://sourceforge.net/bugs/?group_id=612
-
-or send them to the pdl-porters mailing list
-E<lt>pdl-porters@jach.hawaii.eduE<gt>.
+issues tracker at L<https://github.com/PDLPorters/pdl/issues>
+or send them to the pdl-devel mailing list
+(see L<http://pdl.perl.org/?page=mailing-lists>).
 
 
 =head1 COPYRIGHT
