@@ -3,6 +3,11 @@
 # the appropriate gdriver (GL or VRML) items defined here are common
 # to both
 # 
+
+# A function declaration so indirect object method works when defining $ev
+# in new_viewport:
+sub PDL::Graphics::TriD::EventHandler::new;
+
 package PDL::Graphics::TriD::Window;
 use PDL::Graphics::TriD::ViewPort;
 use Data::Dumper;
@@ -67,7 +72,11 @@ sub new_viewport {
 	 use PDL::Graphics::TriD::ArcBall;
 	 use PDL::Graphics::TriD::SimpleScaler;
 	 use PDL::Graphics::TriD::Control3D;
-    use PDL::Graphics::TriD::GL;  
+         if (defined($PDL::Graphics::TriD::offline) and $PDL::Graphics::TriD::offline==1 ) {
+            eval "use PDL::Graphics::TriD::VRML";  
+         } else {
+            eval "use PDL::Graphics::TriD::GL";  
+         }
 
 	 my $ev = $options->{EHandler};
 	 $ev = new PDL::Graphics::TriD::EventHandler($vp) unless defined($ev);
